$TITLE	Analysis of EU Carbon Emissions Trading Schemes using MAC curves

$ontext
===============================================================================
GAMS (Release 21.0) source code to replicate results of

		ZEW Discussion Paper 04-40:
	 Assessing National Allocation Plans in Europe:
	      An Interactive Simulation Approach

C. Boehringer, T. Hoffmann, A. Lange, A. Loeschel, and U. Moslener
Centre for European Economic Reserach (ZEW), Mannheim

correspondence: boehringer@zew.de

Mannheim June, 2004
===============================================================================
$offtext


*==== Model Dimensions and Data
SET	r	Regions within EU emissions trading scheme
	/
	AUT	Austria,
	BEL	Belgium,
	DEU	Germany,
	DNK	Denmark,
	ESP	Spain,
	FIN	Finland,
	FRA	France,
	GBR	United Kingdom,
	GRC	Greece,
	IRL	Ireland,
	ITA	Italy,
	NLD	Netherlands,
	PRT	Portugal,
	SWE	Sweden
	/;

SET	i	Segments of economy
	/
	DIR	Directive sectors,
	NDIR	Non-Directive sectors
	/;

SET	dir(i) /DIR/, ndir(i) /NDIR/;


Table	carbonstat	Benchmark carbon emission summary (in Mt of C)
* Source: EUROSTAT (2002), Energy Database,ISBN/ISSN 92-894-3300-0		
     C_90_Total  C_97_Total    C_97_DIR   C_97_NDIR
AUT        15.0        16.2         5.6        10.6
BEL        32.1        36.0        11.6        24.4
DEU       259.3       228.4       101.1       127.3
DNK        15.2        18.7         9.7         9.0
ESP        58.9        71.1        27.6        43.5
FIN        14.6        16.4         9.0         7.4
FRA        98.8       100.3        21.1        79.2
GBR       157.0       146.9        56.8        90.1
GRC        21.6        25.3        12.0        13.3
IRL         8.1        10.0         4.2         5.8
ITA       108.9       111.8        44.3        67.5
NLD        51.1        56.6        19.0        37.6
PRT        11.2        13.5         5.4         8.1
SWE        14.4        15.2         3.7        11.5 ;
* Key:
* C_90_Total:	Total carbon emissions in 1990 by region  
* C_97_Total:	Total carbon emissions in 1997 by region    
* C_97_DIR:	Carbon emissions of Directive sectors in 1997 by region    
* C_97_NDIR:	Carbon emissions of Non-Directive sectors in 1997 by region


TABLE	mac_coef(r,i,*)	Exogenous coefficients for MAC function (here: polynomial of third degree)
* Source: Own calculations based on European CGE model (Boehringer 2002: 
* Applied Economics, 34, 523-533)
       	   DIR.a1      DIR.a2      DIR.a3     NDIR.a1     NDIR.a2     NDIR.a3			          								       
AUT    	 33.89602     6.23977     9.38573   153.67840    11.28374    34.89848			          								       
BEL    	 13.60163    -0.48508     0.98647    32.68014     2.28401     0.35231			          								       
DEU    	  1.60372     0.00318     0.00042     5.76568     0.08324     0.00095			          								       
DNK    	  8.56613    -1.81555     0.45910    94.96873    29.04864    -0.77840			          								       
ESP    	  6.28601    -0.00715     0.07213    18.32066     0.77646     0.01453			          								       
FIN    	 26.44297     3.40724     1.00766   104.06960    30.23331    16.55028			          								       
FRA    	 11.26670     0.59175     0.25369     8.85555     0.23857     0.00387			          								       
GBR    	  4.07568     0.07888     0.00764     6.96756     0.11765     0.00188			          								       
GRC    	 19.52391    -1.08455     0.44979    61.58611     2.87499     2.35554			          								       
IRL    	  8.55214    19.52084    15.70231   169.52670    61.00378    41.42915			          								       
ITA    	  4.41291     0.10278     0.01290    12.77975    -0.40161     0.11182			          								       
NLD    	  3.61171     1.22083     0.08135    18.21548     0.51576     0.07399			          								       
PRT    	 29.19865    -1.43556     9.85353    83.65847    28.47781    -1.26674			          								       
SWE    	 49.50944     0.32218    38.25903   104.01410    14.25379    -0.06324			          								       


PARAMETER eu_bsa(r)	Carbon emission reduction by region under EU_BSA wrt 1990 (in percent)	
* Source: EU (1999) Preparing for Implementation of the Kyoto Protocol
* available at: http://europa.eu.int/comm/environmen/docum/99230-en.pdf
	/ AUT  13.0,    BEL   7.5,    DEU  21.0,    DNK  21.0,    ESP -15.0,    FIN  0.0,    FRA   0.0,
	  GBR  12.5,    GRC -25.0,    IRL -13.0,    ITA   6.5,    NLD   6.0,    PRT -27.0,   SWE  -4.0
	/;  

SCALAR	exr	Exchange rate EURO97 in USD97  / 1.134 /;
*. source AMECO: http://europa.eu.int/comm/economy_finance/indicators/annual_macro_economic_database/ameco_applet.htm

Scalar	CO2inC	Conversion factor from carbon dioxide to carbon ;
CO2inC = 12/44;


*	Compute percentage reduction targets w.r.t 1990 and 1997
PARAMETER	cutback		Percentage reduction targets;

cutback(r,"1990")     = eu_bsa(r);
cutback("EUR","1990") = 100*sum(r,(cutback(r,"1990") /100)* carbonstat(r,"C_90_Total"))
						       /sum(r, carbonstat(r,"C_90_Total"));

cutback(r,"1997")     = 100*(1 - ( (1- cutback(r,"1990") /100)*carbonstat(r,"C_90_Total"))
					/carbonstat(r,"C_97_Total"));

cutback("EUR","1997") = 100*sum(r,(cutback(r,"1997")/100)* carbonstat(r,"C_97_Total"))
					/sum(r, carbonstat(r,"C_97_Total"));

OPTION cutback:1:1:1;
DISPLAY cutback;

*	For scenarios without hybrid carbon regulation (scenarios: NoTrade and TRD) assign some arbitrary 
*	allocation factor to initialize	emission partitioning between DIR and NDIR sectors - here: lambda0 = 0.5
*	(the partitioning effectively only matters for the hybrid regulation scenarios)

Scalar	lambda0		arbitrary allocation factor to initialize emission partitioning;
lambda0 = 0.5;

PARAMETER target(*,*)	Effective carbon emission reduction requirement in Mtons of carbon;

target("DIR",r)		=  carbonstat(r,"C_97_DIR") - lambda0 * carbonstat(r,"C_97_DIR");
target("NDIR",r)	=  carbonstat(r,"C_97_NDIR") - (carbonstat(r,"C_90_Total")*(1-cutback(r,"1990")/100) 
					- lambda0 * carbonstat(r,"C_97_DIR"));

*	Assignment of MAC curve coefficients
*	Approximations of MACs: MAC = a1*d + a2*d**2 + a3*d**3

PARAMETER a1, a2, a3;
a1(i,r)	 = mac_coef(r,i,"a1");
a2(i,r)	 = mac_coef(r,i,"a2");
a3(i,r)	 = mac_coef(r,i,"a3");

DISPLAY a1,a2,a3,target;

*	Define subset of regions if some regions should be omitted from analysis
SET	re(r);  re(r) = YES;


*==== Model Definition (as a Mixed Complementarity Problem) 

POSITIVE VARIABLES
	p(i,r)		Marginal abatement cost by sector i in region r,
	pfx		Internationally tradable permit price, 
	pd(r)		Domestically tradable permit price in region r,
	d(i,r)		Abatement by sector i in region r,
	x(i,r)		Exports of permits by sector i in region r to international market, 
	m(i,r)		Imports of permits by sector i in region r from international market, 
	xd(i,r)		Exports of permits by sector i in region r to domestic market,
	md(i,r)		Imports of permits by sector i in region r from domestic market;


EQUATIONS
	mkt_p(i,r)	Market clearance for abatement by sector i in region r,
	mkt_pd(r)	Market clearance for domestically tradable permits in region r,
	mkt_pfx		Market clearance for internationally tradable permits,
	zprf_d(i,r)	Zero profit condition for abatement of sector i in region r,
	zprf_m(i,r)	Zero profit condition for permit imports of sector i in region r from international market,
	zprf_x(i,r)	Zero profit condition for permit exports of sector i in region r to international market,
	zprf_md(i,r)	Zero profit condition for permit imports of sector i in region r from domestic market,
	zprf_xd(i,r)	Zero profit condition for permit exports of sector i in region r to domestic market;


mkt_p(i,re)..		d(i,re)  + m(i,re) + md(i,re)	=e= target(i,re) + x(i,re) +xd(i,re) ;
mkt_pd(re)..		sum(i, xd(i,re))		=e= sum(i, md(i,re)) ;
mkt_pfx..		sum((i,re), x(i,re))		=e= sum((i,re), m(i,re)) ;
zprf_m(i,re)..		pfx				=e= p(i,re);
zprf_x(i,re)..		p(i,re)				=e= pfx;
zprf_md(i,re)..		pd(re)				=e= p(i,re);
zprf_xd(i,re)..		p(i,re)				=e= pd(re);
zprf_d(i,re)..		a1(i,re)*d(i,re) + a2(i,re)*d(i,re)**2 + a3(i,re)*d(i,re)**3	=e= p(i,re);

MODEL  simac /mkt_p.p, mkt_pd.pd, mkt_pfx.pfx, zprf_d.d, zprf_m.m, zprf_x.x, zprf_md.md, zprf_xd.xd /;

simac.iterlim = 8000;

*==== Scenario Definition and Reporting

SET	sc	Scenarios 
	/
	NoTrade		No international trade in emission rights (domestic uniform carbon tax),
	Trade		Comprehensive international emissions trading,
	NAP_Opt		Efficient hybrid implementation of EU emission trading,
	NAP_Unity	National allocation plans with exogenous emission-base allocation factor of unity
	/,

	notrade(sc)	/NoTrade/,
	trade(sc)	/Trade/,

	naps(sc)	/NAP_Opt, NAP_Unity/,
	nap_opt(sc)	/NAP_Opt/,
	nap_unity(sc)	/NAP_Unity/,

	runsc(sc)	/NoTrade, Trade, NAP_Opt, NAP_Unity/; 

PARAMETER
	cost		Summary - total compliance costs (in millions of USD),
	mac		Summary - marginal abatement costs (in USD per ton of carbon),
	domabate	Summary - domestic abatement,
	lambda		Summary - allocation factor for emission allowances,
	reduction	Summary - emission reduction in percent vis-a-vis base-year emissions;


*	Scenario Trade is the benchmark for defining efficient allocation factors in a hybrid system.
*	We therefore do an initial solve for comprehensive trading to determine the optimal allocation factor.
x.UP(i,re) = +INF;
m.UP(i,re) = +INF;
pfx.UP	   = +INF;

SOLVE simac using mcp;
lambda(re,"NAP_Opt")	= (carbonstat(re,"C_90_Total")*(1-cutback(re,"1990")/100) 
				- (carbonstat(re,"C_97_NDIR")-d.l("NDIR",re))) / carbonstat(re,"C_97_DIR");


LOOP(SC$RUNSC(SC),
	x.LO(i,re)	= 0;	
	m.LO(i,re)	= 0;
	xd.LO("DIR",re)	= 0;
	md.LO("DIR",re)	= 0;
	pfx.LO		= 0;

	x.UP(i,re)	= +inf;
	m.UP(i,re)	= +inf;
	xd.UP("DIR",re)	= +inf;
	md.UP("DIR",re)	= +inf;
	pfx.UP		= +inf;

	IF(notrade(sc),
* No international emissions trading:
	x.FX(i,re)	= 0;
	m.FX(i,re)	= 0;
	pfx.FX		= 0;
	);


	IF(trade(sc),
* Comprehensive international emissions trading:
	x.UP(i,re)	= +INF;
	m.UP(i,re)	= +INF;
	pfx.UP		= +INF;
	);


	IF(nap_opt(sc),
* Efficient implementation of hybrid NAP system
	target("DIR",re)	= carbonstat(re,"C_97_DIR") - lambda(re,"NAP_Opt") * carbonstat(re,"C_97_DIR");
	target("NDIR",re)	= carbonstat(re,"C_97_NDIR") - (carbonstat(re,"C_90_Total")*(1-cutback(re,"1990")/100) 
					- lambda(re,"NAP_Opt") *carbonstat(re,"C_97_DIR"));
	x.FX("NDIR",re)		= 0;
	m.FX("NDIR",re)		= 0;
	pfx.UP			= +INF;
	xd.FX("DIR",re)		= 0;
	md.FX("DIR",re)		= 0;
	);

	IF(nap_unity(sc),
* Implementation of hybrid NAP system with emission based allocation factor of unity (base year: 1997)
	target("DIR",re)	= carbonstat(re,"C_97_DIR") - 1* carbonstat(re,"C_97_DIR");
	target("NDIR",re)	= carbonstat(re,"C_97_NDIR") - (carbonstat(re,"C_90_Total")*(1-cutback(re,"1990")/100) 
					- 1*carbonstat(re,"C_97_DIR"));
	x.FX("NDIR",re)		= 0;
	m.FX("NDIR",re)		= 0;
	pfx.UP			= +INF;
	xd.FX("DIR",re)		= 0;
	md.FX("DIR",re)		= 0;
	);

md.l(i,re) = 0; xd.l(i,re) = 0; m.l(i,re) = 0; x.l(i,re) = 0; d.l(i,re) = 0; pfx.l = 0; p.l(i,re) = 0;

SOLVE simac using mcp;


cost(re,"DIR",sc)		= eps + ROUND(  (  sum(i$DIR(I), (1/2)*a1(i,re)*d.l(i,re)**2 
							+ (1/3)*a2(i,re)*d.l(i,re)**3  
							+ (1/4)*a3(i,re)*d.l(i,re)**4  
							)
							+ sum(i, (m.l(i,re) - x.l(i,re))*pfx.l)), 1);


cost(re,"NDIR",sc)		= eps + ROUND(  (  sum(i$NDIR(i), (1/2)*a1(i,re)*d.l(i,re)**2 
							+ (1/3)*a2(i,re)*d.l(i,re)**3  
							+ (1/4)*a3(i,re)*d.l(i,re)**4  
							)), 1);

cost(re,"Total",sc)		= cost(re,"DIR",sc) + cost(re,"NDIR",sc);

mac(re,i,sc)			= eps + ROUND(p.l(i,re),1);

domabate(re,i,sc)		= eps + ROUND(d.l(i,re),2);

reduction(re,"DIR",sc)		= ROUND(100* d.l("DIR",re)/carbonstat(re,"C_97_DIR"), 1);

reduction(re,"NDIR",sc)		= ROUND(100* d.l("NDIR",re)/carbonstat(re,"C_97_DIR"), 1);

reduction(re,"TOTAL",sc)	= ROUND(100* sum(i,d.l(i,re))/carbonstat(re,"C_97_TOTAL"), 1);

lambda(re,sc)$naps(sc)		= 1$(not d.l("NDIR",re)) + [(carbonstat(re,"C_90_Total")*(1-cutback(re,"1990")/100) 
					- (carbonstat(re,"C_97_NDIR")-d.l("NDIR",re))) / carbonstat(re,"C_97_DIR")]$(d.l("NDIR",re)) ;


);

DISPLAY cost, mac, domabate,lambda, reduction;


*==== Replicate Tables of Paper
PARAMETER c_2010	Projected carbon emissions by region in 2010 
* Source: Energy Policies of IEA Countries - 2001 Review (Compendium), IEA publications  
	/ AUT  17.5,    BEL  31.4,    DEU 228.5,    DNK  16.1,    ESP  78.8,    FIN  17.7,    FRA 126.0,    GBR 159.5,    
	  GRC  36.5,    IRL  12.8,    ITA 123.0,    NLD  50.7,    PRT  16.6,    SWE  14.5 /;


PARAMETER 
	table_2		Table 2 of paper "CO2 emissions and reduction requirements", 
	table_4		Table 4 of paper "Marginal abatement costs and total compliance costs"
	table_5		Table 5 of paper "Allocation factors and emission reduction";

*	Generate Table 2 of paper
table_2(re, "1990_a")	= ROUND(1/CO2inC*carbonstat(re, "C_90_Total"),1); table_2("EUR","1990_a") = sum(re,table_2(re,"1990_a"));
table_2(re, "1997_a")	= ROUND(1/CO2inC*carbonstat(re, "C_97_Total"),1); table_2("EUR","1997_a") = sum(re,table_2(re,"1997_a"));
table_2(re,"2010_a")	= ROUND(1/CO2inC*c_2010(re),1); table_2("EUR","2010_a") = sum(re,table_2(re,"2010_a"));

table_2(re,"1990_p")	= eps + cutback(re,"1990");
table_2("EUR","1990_p") = ROUND(100*sum(re,(table_2(re,"1990_p")/100)* table_2(re,"1990_a"))/sum(re, table_2(re,"1990_a")), 1);
table_2(re,"1997_p")	= eps + ROUND(100*(1 - ( (1- table_2(re,"1990_p")/100)*table_2(re,"1990_a"))/table_2(re,"1997_a")),1);
table_2("EUR","1997_p") = ROUND(100*sum(re,(table_2(re,"1997_p")/100)* table_2(re,"1997_a"))/sum(re, table_2(re,"1997_a")), 1);
table_2(re,"2010_p")	= eps + ROUND(100*(1 - ( (1- table_2(re,"1990_p")/100)*table_2(re,"1990_a"))/table_2(re,"2010_a")),1);
table_2("EUR","2010_p") = ROUND(100*sum(re,(table_2(re,"2010_p")/100)* table_2(re,"2010_a"))/sum(re, table_2(re,"2010_a")), 1);

*	Generate Table 4 of paper
table_4(re, "MAC_NoTrade")		= eps + ROUND(exr*CO2inC*mac(re,"DIR","NoTrade"),1);
table_4(re, "MAC_NAP_Opt")		= eps + ROUND(exr*CO2inC*mac(re,"DIR","NAP_Opt"),1);
table_4(re, "MAC_NDIR_NAP_Opt")		= eps + ROUND(exr*CO2inC*mac(re,"NDIR","NAP_Opt"),1);
table_4(re, "MAC_DIR_NAP_Unity")	= eps + ROUND(exr*CO2inC*mac(re,"DIR","NAP_Unity"),1);
table_4(re, "MAC_NDIR_NAP_Unity")	= eps + ROUND(exr*CO2inC*mac(re,"NDIR","NAP_Unity"),1);

*	Total cost figures in Table 4 are given in millions of EUROs
table_4(re, "Cost_ToT_NoTrade")		= eps + exr*cost(re,"Total","NoTrade");
table_4(re, "Cost_DIR_NoTrade")		= eps + exr*cost(re,"DIR","NoTrade");
table_4(re, "Cost_NDIR_NoTrade")	= eps + exr*cost(re,"NDIR","NoTrade");
table_4(re, "Cost_ToT_NAP_Opt")		= eps + exr*cost(re,"Total","NAP_Opt");
table_4(re, "Cost_DIR_NAP_Opt")		= eps + exr*cost(re,"DIR","NAP_Opt");
table_4(re, "Cost_NDIR_NAP_Opt")	= eps + exr*cost(re,"NDIR","NAP_Opt");
table_4(re, "Cost_ToT_NAP_Unity")	= eps + exr*cost(re,"Total","NAP_Unity");
table_4(re, "Cost_DIR_NAP_Unity")	= eps + exr*cost(re,"DIR","NAP_Unity");
table_4(re, "Cost_NDIR_NAP_Unity")	= eps + exr*cost(re,"NDIR","NAP_Unity");

set item /Cost_ToT_NoTrade, Cost_DIR_NoTrade, Cost_NDIR_NoTrade, Cost_ToT_NAP_Opt,	
		  Cost_DIR_NAP_Opt, Cost_NDIR_NAP_Opt, Cost_ToT_NAP_Unity, Cost_DIR_NAP_Unity,
		  Cost_NDIR_NAP_Unity/;

table_4("eur",item)			= sum(re, table_4(re,item));


*	Generate Table 5 of paper
table_5(re, "Lambda_NAP_Opt")		= eps + ROUND(lambda(re,"NAP_Opt"),2);
table_5(re, "Lambda_NAP_Unity")		= eps + ROUND(lambda(re,"NAP_Unity"),2);
table_5(re, "Cut_ToT_NoTrade")		= eps + reduction(re,"TOTAL","NoTrade");
table_5(re, "Cut_DIR_NoTrade")		= eps + reduction(re,"DIR","NoTrade");
table_5(re, "Cut_NDIR_NoTrade")		= eps + reduction(re,"NDIR","NoTrade");
table_5(re, "Cut_ToT_NAP_Opt")		= eps + reduction(re,"TOTAL","NAP_Opt");
table_5(re, "Cut_DIR_NAP_Opt")		= eps + reduction(re,"DIR","NAP_Opt");
table_5(re, "Cut_NDIR_NAP_Opt")		= eps + reduction(re,"NDIR","NAP_Opt");
table_5(re, "Cut_ToT_NAP_Unity")	= eps + reduction(re,"TOTAL","NAP_Unity");
table_5(re, "Cut_DIR_NAP_Unity")	= eps + reduction(re,"DIR","NAP_Unity");
table_5(re, "Cut_NDIR_NAP_Unity")	= eps + reduction(re,"NDIR","NAP_Unity");

display table_2, table_4, table_5;

$libinclude xlexport table_2  tables.xls table_2!table_2 
$libinclude xlexport table_4  tables.xls table_4!table_4 
$libinclude xlexport table_5  tables.xls table_5!table_5 

